pub trait Microtype {
type Inner;
// Required methods
fn new(inner: Self::Inner) -> Self;
fn into_inner(self) -> Self::Inner;
fn inner(&self) -> &Self::Inner;
fn inner_mut(&mut self) -> &mut Self::Inner;
fn convert<T: Microtype<Inner = Self::Inner>>(self) -> T;
}Expand description
A trait implemented by microtypes
Provides some useful common functions for working with microtypes
Required Associated Types
Required Methods
Sourcefn into_inner(self) -> Self::Inner
fn into_inner(self) -> Self::Inner
Consume this microtype and return the value it contains
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".